{
 "metadata": {
  "name": ""
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "# Delaying a connection with a node\n",
      "\n",
      "Nodes allow for all sorts of advanced behavior that is typically done by modifying of extending the code of a neural simulator. In Nengo, the `Node` object allows for custom code to run.\n",
      "\n",
      "In this example, we will implement an `n`-timestep delayed connection by using a node."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import numpy as np\n",
      "import matplotlib.pyplot as plt\n",
      "%matplotlib inline\n",
      "\n",
      "import nengo\n",
      "%load_ext nengo.ipynb\n",
      "from nengo.processes import WhiteSignal"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "text": [
        "<IPython.core.display.Javascript at 0x7f551c7eb7d0>"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "model = nengo.Network(label=\"Delayed connection\")\n",
      "with model:\n",
      "    # We'll use white noise as input\n",
      "    inp = nengo.Node(WhiteSignal(2, high=5), size_out=1)\n",
      "    A = nengo.Ensemble(40, dimensions=1)\n",
      "    nengo.Connection(inp, A)\n",
      "\n",
      "# We'll make a simple object to implement the delayed connection\n",
      "class Delay(object):\n",
      "    def __init__(self, dimensions, timesteps=50):\n",
      "        self.history = np.zeros((timesteps, dimensions))\n",
      "    def step(self, t, x):\n",
      "        self.history = np.roll(self.history, -1)\n",
      "        self.history[-1] = x\n",
      "        return self.history[0]\n",
      "\n",
      "dt = 0.001\n",
      "delay = Delay(1, timesteps=int(0.2 / 0.001))\n",
      "\n",
      "with model:\n",
      "    delaynode = nengo.Node(delay.step, size_in=1, size_out=1)\n",
      "    nengo.Connection(A, delaynode)\n",
      "    \n",
      "    # Send the delayed output through an ensemble\n",
      "    B = nengo.Ensemble(40, dimensions=1)\n",
      "    nengo.Connection(delaynode, B)\n",
      "    \n",
      "    # Probe the input at the delayed output\n",
      "    A_probe = nengo.Probe(A, synapse=0.01)\n",
      "    B_probe = nengo.Probe(B, synapse=0.01)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Run for 2 seconds\n",
      "with nengo.Simulator(model) as sim:\n",
      "    sim.run(2)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 3
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Plot the results\n",
      "plt.subplot(2, 1, 1)\n",
      "plt.plot(sim.trange(), sim.data[A_probe], lw=2)\n",
      "plt.title(\"Input\")\n",
      "plt.subplot(2, 1, 2)\n",
      "plt.plot(sim.trange(), sim.data[B_probe], lw=2)\n",
      "plt.axvline(0.2, c='k')\n",
      "plt.title(\"Delayed output\")\n",
      "plt.tight_layout();"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAagAAAEaCAYAAABEsMO+AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nguBLxEAJgiAIvuT/Ae6NzNyEDE5pAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f54e0f6a550>"
       ]
      }
     ],
     "prompt_number": 4
    }
   ],
   "metadata": {}
  }
 ]
}